<?php
namespace FiloBlu\Rma\Plugin\Model\Order;

use FiloBlu\Rma\Handlers\CanCreateRmaHandler;
use Magento\Sales\Api\Data\OrderExtension;
use Magento\Sales\Api\Data\OrderExtensionFactory;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;

class OrderGet
{
    /**
     * @var CanCreateRmaHandler
     */
    private $canCreateRmaHandler;
    /**
     * @var OrderExtensionFactory
     */
    private $orderExtensionFactory;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * OrderGet constructor.
     * @param CanCreateRmaHandler $canCreateRmaHandler
     * @param OrderExtensionFactory $orderExtensionFactory
     * @param LoggerInterface $logger
     */
    public function __construct(
        CanCreateRmaHandler $canCreateRmaHandler,
        OrderExtensionFactory $orderExtensionFactory,
        LoggerInterface $logger){
        $this->canCreateRmaHandler = $canCreateRmaHandler;
        $this->orderExtensionFactory = $orderExtensionFactory;
        $this->logger = $logger;
    }

    /**
     * @param OrderRepositoryInterface $subject
     * @param $resultOrder
     * @return mixed
     */
    public function afterGet(
        OrderRepositoryInterface $subject,
        $resultOrder
    ) {
       try{

           $this->addReturnableFlag($resultOrder);

       }catch (\Exception $e){
           $this->logger->critical($e->getMessage());
       }catch (\Throwable $t){
           $this->logger->critical($t->getMessage());
       }
        return $resultOrder;
    }


    /**
     * @param OrderInterface $order
     */
    private function addReturnableFlag(OrderInterface $order){
        $extensionAttributes = $order->getExtensionAttributes();
        /** @var OrderExtension $orderExtension */
        $orderExtension = $extensionAttributes ? $extensionAttributes : $this->orderExtensionFactory->create();
        $isReturnable = $this->canCreateRmaHandler->getCanOrderCreateRma($order);
        $orderExtension->setReturnable($isReturnable);
        $order->setExtensionAttributes($orderExtension);
    }

}
